/*
* file CcAccessControlEntry.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcAccessControlEntry
*
* (C) Copyright IBM Corporation 2012.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/
package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.WvcmException;

/**
 * <p>
 * An access control entry provides a triple of a role kind, identity and permission set
 * as part of an effective ACL for a VOB resource.
 * <p>
 * This interface provides an aggregate object for handling such an entry.
 * </p>
 */
public interface CcAccessControlEntry {
    
    public enum PrincipalKind {
        NONE("<id-kind-none>"),
        USER("User"),
        GROUP("Group"),
        EVERYONE("Everyone"),
        OWNER_USER("Owner-User"),
        OWNER_GROUP("Owner-Group"),
        ROLE("Role");
        
        private final String m_kind;

        PrincipalKind(String kind) {
            m_kind = kind;
        }

        public String toString() {
            return m_kind;
        }
    }
  
    /**
     * Get the kind of principal for which this entry applies.
     */
    public PrincipalKind getPrincipalKind();
    
    /**
     * Get the principal name for the entry.  Includes domain name when applicable
     */
    public String getPrincipalName();
    
    /**
     * Get the human readable permissions for this entry.
     */
    public String getPermissions() throws WvcmException;

}
